@@ -18,13 +18,14 @@
 # Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 # 02110-1301, USA.
 
+import base64
 import logging
 import os
 import shutil
 import subprocess
 import tempfile
 from contextlib import closing
-from urllib.parse import quote
+from urllib.parse import quote, urlparse
 from urllib.request import Request, urlopen
 
 import apt_pkg
@@ -111,7 +112,23 @@ class TagFile(Archive):
                 + ftppath
                 + suffix
             )
-            req = Request(url)
+            parsed = urlparse(url)
+            if parsed.username:
+                host_without_auth = parsed.hostname
+                if parsed.port:
+                    host_without_auth += ":" + str(parsed.port)
+                req = Request(
+                    parsed._replace(netloc=host_without_auth).geturl()
+                )
+                base64string = base64.b64encode(
+                    ("%s:%s" % (parsed.username, parsed.password)).encode()
+                )
+                req.add_header(
+                    "Authorization", "Basic %s" % base64string.decode()
+                )
+            else:
+                req = Request(url)
+
             filename = None
 
             if req.type != "file":
