@@ -201,6 +201,13 @@ def parse_options(argv):
     return options
 
 
+# Possibly should source this from dpkg's varianttable, but we want to run
+# this on machines that are not running the latest dpkg...
+isa_tag_to_abi_tag = {
+    "amd64v3": "amd64",
+}
+
+
 def main(argv):
     options = parse_options(argv)
 
@@ -209,16 +216,24 @@ def main(argv):
     else:
         germinate_logging(logging.INFO)
 
-    g = Germinator(options.arch)
+    isa_tag = options.arch
+    abi_tag = isa_tag_to_abi_tag.get(isa_tag, isa_tag)
+
+    g = Germinator(abi_tag)
     g._always_follow_build_depends = options.always_follow_build_depends
 
     if options.apt_config:
         archive = germinate.archive.AptArchive(options.apt_config)
     else:
+        # It isn't strictly correct to just pass isa_tag here: for an amd64v3
+        # image we should really probe for amd64v3, amd64v3, amd64 Packages
+        # files in order (and possibly download all of these in the case of
+        # partial variants) but for now this actually works fine (as Ubuntu
+        # does not publish amd64v2 and amd64v3 is a total variant).
         archive = germinate.archive.TagFile(
             options.dist,
             options.components,
-            options.arch,
+            isa_tag,
             options.mirrors,
             source_mirrors=options.source_mirrors,
             installer_packages=options.installer,
@@ -240,10 +255,15 @@ def main(argv):
         sys.exit(1)
 
     try:
+        """Accept blacklist/blocklist for a transitional period"""
+        if os.path.exists("blocklist"):
+            bl_cklist = "blocklist"
+        else:
+            bl_cklist = "blacklist"
         with Seed(
-            options.seeds, options.release, "blacklist", options.vcs
-        ) as blacklist:
-            g.parse_blacklist(structure, blacklist)
+            options.seeds, options.release, bl_cklist, options.vcs
+        ) as blocklist:
+            g.parse_blocklist(structure, blocklist)
     except SeedError:
         pass
 
@@ -254,6 +274,7 @@ def main(argv):
 
     for seedname in structure.names + ["extra"]:
         g.write_full_list(structure, seedname, seedname)
+        g.write_full_list_json(structure, seedname + ".json", seedname)
         g.write_seed_list(structure, seedname + ".seed", seedname)
         g.write_seed_recommends_list(
             structure, seedname + ".seed-recommends", seedname
@@ -272,6 +293,7 @@ def main(argv):
         )
 
     g.write_all_list(structure, "all")
+    g.write_all_list_json(structure, "all.json")
     g.write_all_source_list(structure, "all.sources")
     g.write_all_snap_list(structure, "all.snaps")
 
@@ -304,6 +326,8 @@ def main(argv):
                 os.path.join("rdepends", "ALL", pkg),
             )
 
-    g.write_blacklisted(structure, "blacklisted")
+    g.write_blocklisted(structure, "blocklisted")
+    """Create a symlink for a transitional period"""
+    os.symlink("blocklisted", "blacklisted")
 
     return 0
