@@ -194,7 +194,8 @@ def main(argv):
                 packages.extend(value)
             else:
                 raise NotImplementedError(
-                    "seed_packages: support for type '{type(value)}' not implemented"
+                    "seed_packages: support for type '{type(value)}' not "
+                    "implemented"
                 )
 
         return packages
