@@ -17,6 +17,8 @@
 # Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 # 02110-1301, USA.
 
+import json
+
 from germinate.scripts import germinate_main
 from germinate.tests.helpers import TestCase
 
@@ -71,11 +73,18 @@ class TestGerminate(TestCase):
         supported = self.parseOutput("supported")
         self.assertTrue("hello" in supported)
         self.assertTrue("hello-dependency" in supported)
+        with open("supported.json") as fp:
+            supported_json = json.load(fp)
+        self.assertEqual(set(supported_json), set(supported))
 
         all_ = self.parseOutput("all")
         self.assertTrue("hello" in all_)
         self.assertTrue("hello-dependency" in all_)
 
+        with open("all.json") as fp:
+            all_json = json.load(fp)
+        self.assertEqual(set(all_json), set(all_))
+
     def test_snap(self):
         # Need Packages
         self.addSource(
